@@ -8,15 +8,16 @@ use crate::error::Error;
 
 /// Read the shared secret from a file.
 pub fn read_shared_secret(path: &Path) -> Result<Vec<u8>, Error> {
-    if !path.exists() {
-        return Err(Error::FileNotFound(
-            "Secret. Did you start the daemon at least once?".into(),
-        ));
-    }
-
-    let mut file = File::open(path)?;
+    let mut file = File::open(path).map_err(|err| {
+        Error::IoPathError(
+            path.to_path_buf(),
+            "opening secret file. Did you start the daemon at least once?",
+            err,
+        )
+    })?;
     let mut buffer = Vec::new();
-    file.read_to_end(&mut buffer)?;
+    file.read_to_end(&mut buffer)
+        .map_err(|err| Error::IoPathError(path.to_path_buf(), "reading secret file", err))?;
 
     Ok(buffer)
 }
@@ -36,8 +37,10 @@ pub fn init_shared_secret(path: &Path) -> Result<(), Error> {
         .take(PASSWORD_LEN)
         .collect();
 
-    let mut file = File::create(path)?;
-    file.write_all(&secret.into_bytes())?;
+    let mut file = File::create(&path)
+        .map_err(|err| Error::IoPathError(path.to_path_buf(), "creating shared secret", err))?;
+    file.write_all(&secret.into_bytes())
+        .map_err(|err| Error::IoPathError(path.to_path_buf(), "writing shared secret", err))?;
 
     // Set proper file permissions for unix filesystems
     #[cfg(not(target_os = "windows"))]
@@ -46,12 +49,12 @@ pub fn init_shared_secret(path: &Path) -> Result<(), Error> {
         let mut permissions = file
             .metadata()
             .map_err(|err| {
-                Error::Generic(format!("Failed to set secret file permissions:\n{err}"))
+                Error::IoPathError(path.to_path_buf(), "reading secret file metadata", err)
             })?
             .permissions();
         permissions.set_mode(0o640);
         std::fs::set_permissions(path, permissions).map_err(|err| {
-            Error::Generic(format!("Failed to set secret file permissions:\n{err}"))
+            Error::IoPathError(path.to_path_buf(), "setting secret file permissions", err)
         })?;
     }
 
